@@ -5,7 +5,7 @@ require 5.006_000;
 
 # Keep this < 1.00, so people can tell the fake
 #  mro.pm from the real one
-our $VERSION = '0.08_01';
+our $VERSION = '0.14_01';
 
 BEGIN {
     # Alias our private functions over to
@@ -49,17 +49,19 @@ MRO::Compat - mro::* interface compatibility for Perls < 5.9.5
 
 =head1 SYNOPSIS
 
+   package PPP;      use base qw/Exporter/;
+   package X;        use base qw/PPP/;
+   package Y;        use base qw/PPP/;
+   package Z;        use base qw/PPP/;
+
    package FooClass; use base qw/X Y Z/;
-   package X;        use base qw/ZZZ/;
-   package Y;        use base qw/ZZZ/;
-   package Z;        use base qw/ZZZ/;
 
    package main;
    use MRO::Compat;
    my $linear = mro::get_linear_isa('FooClass');
    print join(q{, }, @$linear);
 
-   # Prints: "FooClass, X, ZZZ, Y, Z"
+   # Prints: FooClass, X, PPP, Exporter, Y, Z
 
 =head1 DESCRIPTION
 
@@ -113,20 +115,16 @@ methods from C<UNIVERSAL> and its parents.
 =cut
 
 sub __get_linear_isa_dfs {
-    no strict 'refs';
+    my @check = shift;
+    my @lin;
 
-    my $classname = shift;
-
-    my @lin = ($classname);
-    my %stored;
-    foreach my $parent (@{"$classname\::ISA"}) {
-        my $plin = __get_linear_isa_dfs($parent);
-        foreach (@$plin) {
-            next if exists $stored{$_};
-            push(@lin, $_);
-            $stored{$_} = 1;
-        }
+    my %found;
+    while (defined(my $check = shift @check)) {
+        push @lin, $check;
+        no strict 'refs';
+        unshift @check, grep !$found{$_}++, @{"$check\::ISA"};
     }
+
     return \@lin;
 }
 
@@ -148,7 +146,7 @@ sub __get_linear_isa {
 
 This allows the C<use mro 'dfs'> and
 C<use mro 'c3'> syntaxes, providing you
-L<use MRO::Compat> first.  Please see the
+C<use MRO::Compat> first.  Please see the
 L</USING C3> section for additional details.
 
 =cut
@@ -212,8 +210,8 @@ sub __get_mro {
 =head2 mro::get_isarev($classname)
 
 Returns an arrayref of classes who are subclasses of the
-given classname.  In other words, classes who we exist,
-however indirectly, in the @ISA inheritancy hierarchy of.
+given classname.  In other words, classes in whose @ISA
+hierarchy we appear, no matter how indirectly.
 
 This is much slower on pre-5.9.5 Perls with MRO::Compat
 than it is on 5.9.5+, as it has to search the entire
